@@ -532,6 +532,7 @@ class Tela():
         self._altura = altura
         self.cor = cor
         self.fps = fps
+        self.atualizar = True
 
     @property
     def largura(self):
@@ -540,33 +541,43 @@ class Tela():
     @property
     def altura(self):
         return self._altura
-        
+
 def atualizar_tela():
+    global rodar_threading, tela
+    while rodar_threading:
+        pygame.time.Clock().tick( tela.fps )
+        tela.atualizar = True
+
+def verificar_eventos():
     global rodar_threading, tela
     tela._tela = pygame.display.set_mode( [tela.largura, tela.altura] ) 
     while rodar_threading:
-        pygame.time.Clock().tick( tela.fps)
-                
-        #preenche teala com cor de fundo
-        tela._tela.fill(tela.cor )
-        
-        #exibe objetos
-        for objeto in lista_de_objetos:
-            if( objeto.visivel ):
-                tela._tela.blit( objeto.imagem, objeto.area_da_imagem )
+        pygame.time.Clock().tick( 400 )
 
-        #exibe textos        
-        for texto in lista_de_textos:
-            if( texto.visivel ):
-                tela._tela.blit(texto.texto, texto.posicao)
+        if( tela.atualizar == True ):
+                    
+            #preenche teala com cor de fundo
+            tela._tela.fill(tela.cor )
+            
+            #exibe objetos
+            for objeto in lista_de_objetos:
+                if( objeto.visivel ):
+                    tela._tela.blit( objeto.imagem, objeto.area_da_imagem )
 
-        #exibe botões
-        for botao in lista_de_botoes:
-            if( botao.visivel ):
-                pygame.draw.rect( tela._tela, botao.cor, botao.rect )
+            #exibe textos        
+            for texto in lista_de_textos:
+                if( texto.visivel ):
+                    tela._tela.blit(texto.texto, texto.posicao)
 
-        pygame.display.flip()
-        
+            #exibe botões
+            for botao in lista_de_botoes:
+                if( botao.visivel ):
+                    pygame.draw.rect( tela._tela, botao.cor, botao.rect )
+
+            pygame.display.flip()
+
+            tela.atualizar = False
+            
         for event in pygame.event.get():
                 if event.type == pygame.QUIT:
                     #faz threadings fecharem
@@ -595,8 +606,8 @@ def abrir_tela(largura=800, altura=600, cor = roxo, fps= 60):
     t_atualizar_tela = threading.Thread( target= atualizar_tela )
     t_atualizar_tela.start()
 
-    #t_verificar_eventos = threading.Thread( target= verificar_eventos )
-    #t_verificar_eventos.start()
+    t_verificar_eventos = threading.Thread( target= verificar_eventos )
+    t_verificar_eventos.start()
     return tela
 
 
